summaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorSteve Huston <shuston@riverace.com>2004-01-06 19:32:04 +0000
committerSteve Huston <shuston@riverace.com>2004-01-06 19:32:04 +0000
commit3956f6f441f59848587c011cc0eb636103adaddd (patch)
tree12c0de03a34a6655c2080a3768e52239a4bd53bd /examples
parenta1e498f1a1aa116a4d00ad50e85c370834f25cfc (diff)
downloadATCD-3956f6f441f59848587c011cc0eb636103adaddd.tar.gz
ChangeLogTag:Tue Jan 6 14:00:12 2004 Steve Huston <shuston@riverace.com>
Diffstat (limited to 'examples')
-rw-r--r--examples/APG/Logging/Trace.h4
-rw-r--r--examples/APG/Logging/Trace_Return.cpp6
-rw-r--r--examples/APG/Logging/Wrap_Macros.cpp6
-rw-r--r--examples/APG/Makefile2
4 files changed, 9 insertions, 9 deletions
diff --git a/examples/APG/Logging/Trace.h b/examples/APG/Logging/Trace.h
index 8662eb3c8e6..c6aec50934b 100644
--- a/examples/APG/Logging/Trace.h
+++ b/examples/APG/Logging/Trace.h
@@ -98,8 +98,8 @@ private:
//////////////////////////////////////////////////
-#if defined (__GNUC__)
-// This stuff only works with g++...
+#if defined (__GNUC__) && (__GNUC__ >= 3 || __GNUC_MINOR__ > 95)
+// This stuff only works with g++ 2.96 and later...
// Listing 3 code/ch03
diff --git a/examples/APG/Makefile b/examples/APG/Makefile
index 869b43797f9..833c3628faf 100644
--- a/examples/APG/Makefile
+++ b/examples/APG/Makefile
@@ -10,7 +10,7 @@
DIRS = Config \
Containers \
-# Logging \
+ Logging \
Misc_IPC \
Proactor \
Processes \
diff --git a/examples/APG/Logging/Trace_Return.cpp b/examples/APG/Logging/Trace_Return.cpp
index 71b04f0e0b7..d466abc43c1 100644
--- a/examples/APG/Logging/Trace_Return.cpp
+++ b/examples/APG/Logging/Trace_Return.cpp
@@ -1,7 +1,7 @@
// $Id$
#if defined (__GNUC__)
// The DEBUG stuff only works with g++...
// Listing 1 code/ch03
#include "Trace.h"
@@ -32,7 +32,7 @@ void foo (void)
int main (int, char *[])
{
- puts ("This example only works on g++\n");
+ puts ("This example only works on g++ 2.96 and later.\n");
return 0;
}
@@ -1,7 +1,7 @@
// $Id$
-#if defined (__GNUC__)
-// The DEBUG stuff only works with g++...
+#if defined (__GNUC__) && (__GNUC__ >= 3 || __GNUC_MINOR__ > 95)
+// The DEBUG stuff only works with g++ 2.96 and later.
// Listing 1 code/ch03
#include "Trace.h"
diff --git a/examples/APG/Logging/Wrap_Macros.cpp b/examples/APG/Logging/Wrap_Macros.cpp
index 1a272a8abe8..73c908272d2 100644
--- a/examples/APG/Logging/Wrap_Macros.cpp
+++ b/examples/APG/Logging/Wrap_Macros.cpp
@@ -1,7 +1,7 @@
// $Id$
#if defined (__GNUC__)
// The macros in Trace.h only work on g++
// Listing 1 code/ch03
#include "Trace.h"
@@ -29,7 +29,7 @@ void foo (void)
int main (int, char *[])
{
- puts ("This example only works on g++\n");
+ puts ("This example only works on g++ 2.96 and later.\n");
return 0;
}
@@ -1,7 +1,7 @@
// $Id$
-#if defined (__GNUC__)
-// The macros in Trace.h only work on g++
+#if defined (__GNUC__) && (__GNUC__ >= 3 || __GNUC_MINOR__ > 95)
+// The macros in Trace.h only work on g++ 2.96 and later.
// Listing 1 code/ch03
#include "Trace.h"